<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:msxsl="urn:schemas-microsoft-com:xslt"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<!-- Information messages -->
<xsl:template match='/ServerLink/Information'>
  <gjs:form
    title='Change Request Properties'
    save='no'
    close='yes'
    delete='no'
    print='no'
    help='no'>
    <p class='caption' style='color: red'>
      <img src="vcmWarning.gif"/>&nbsp;&nbsp;
      <xsl:value-of select='@message'/>
    </p>
  </gjs:form>
</xsl:template>

<xsl:template match="ChangeRequestForm">
  <gjs:form
   title='Change Request Properties'
   jsFile='vc339.js'
   onload='fnLoad();'>
  <xsl:apply-templates />
  </gjs:form>
</xsl:template>

<xsl:template match="ChangeRequest">

  <gjs:tabStrip2>
    <gjs:tabStripTab2
     id='tabChangeRequest'
     divId='divChangeRequest'>
       <label>Mai<u>n</u> Details</label>
       <hint>Main properties of the change request.</hint>
    </gjs:tabStripTab2>
    <gjs:tabStripTab2
     id='tabComments'
     divId='divComments'>
       <label>Co<u>m</u>ments</label>
       <hint>Comments and creation/amendment audit fields. Bold caption indicates existence of comment text.</hint>
    </gjs:tabStripTab2>

    <!-- Include custom tabs here, which could be first- or second-generation ones. Second-gen ones will always be added first. -->
    <xsl:call-template name='customTabs' />
  </gjs:tabStrip2>

  <!-- The main Change Request panel -->
  <div id='divChangeRequest' class='tabPanelVisible' style='min-height: 370px;'>
    <gjs:frame>

      <!-- Set up form column widths -->
      <gjs:columnWidths>
        <gjs:column width='120'/>
        <gjs:column width='480'/>
      </gjs:columnWidths>

      <gjs:fields>

        <gjs:list1
         id='changeRequestType'
         accesskey='T'
         caption='Type'
         width='172'
         value='{@changeRequestType}'
         onchange='Form.fnChanged();fnChangeType(this);'
         readonly='0'>
          <label><u>T</u>ype</label>
          <hint>Select the type of change request</hint>
          <xsl:apply-templates select="/ChangeRequestForm/changeRequestTypes" mode='type'/>
        </gjs:list1>

    <gjs:input
     id='changeRequest'
     accesskey='R'
     size='30'
     maxlength='30'
     value='{@changeRequest}'
     onchange='Form.fnChanged()'
     readonly='0'>
    <xsl:if test='@revision!=""'>
       <xsl:attribute name='readonly'>1</xsl:attribute>        
    </xsl:if>
     <label>Change <u>r</u>equest</label>
     <hint>Enter a change request number, or leave blank to get the next available number. Cannot be amended after saving</hint>
    </gjs:input>

    <gjs:input
     id='name'
     accesskey='Y'
     size='72'
     maxlength='80'
     value='{@name}'
     onchange='Form.fnChanged()'
     readonly='0'>
     <label>Summar<u>y</u></label>
     <hint>Enter a brief description of this change request</hint>
    </gjs:input>

    <gjs:textarea
     id='description'
     accesskey='L'
     rows='12'
     cols='72'
     value='{@description}'
     onchange='Form.fnChanged()'
     readonly='0'>
     <label>Detai<u>l</u>s</label>
     <hint>Enter the details of this change request</hint>
    </gjs:textarea>

    <gjs:input
     id='ownerUserId'
     accesskey='U'
     size='16'
     maxlength='30'
     value='{@ownerUserId}'
     onchange='Form.fnChanged()'
     readonly='0'>
     <label>Owner <u>u</u>ser ID</label>
     <hint>Enter the User Id of the owner of this change request</hint>
    </gjs:input>

    <gjs:calendar
     id='plannedEndDate'
     accesskey='E'
     gjsInternalValue='{@hPlannedEndDate}'>
     <label>Planned <u>e</u>nd date</label>
     <hint>Enter the estimated completion date for this change request. For a date relative to today enter '+n'</hint>
    </gjs:calendar>

    <xsl:variable name="changeRequestType" select="@changeRequestType"/>
    <gjs:list1
     id='status'
     accesskey='A'
     width='172'
     value='{@status}'
     onchange='Form.fnChanged()'>
      <xsl:choose>
        <xsl:when test="count(/ChangeRequestForm/changeRequestTypes/changeRequestType[@changeRequestType=$changeRequestType]/changeRequestStatii/changeRequestStatus)=0">
          <xsl:attribute name="disabled" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:if test='@status=""'>
            <!-- Blank status is the current value -->
            <item>
              <label></label>
              <value></value>
            </item>
          </xsl:if>
          <xsl:apply-templates select='/ChangeRequestForm/changeRequestTypes/changeRequestType[@changeRequestType=$changeRequestType]/changeRequestStatii/changeRequestStatus' mode='currentStatus'>
            <xsl:sort select='@statusSequence' data-type='number'/>
          </xsl:apply-templates>
        </xsl:otherwise>
      </xsl:choose>
      <label>St<u>a</u>tus</label>
      <hint>Select the status of this change request, if any are defined for the type</hint>
    </gjs:list1>

  </gjs:fields>

  <gjs:inputHidden id='revision' value='{@revision}'/>
  <gjs:inputHidden id='oldChangeRequest' value='{@changeRequest}'/>
  <gjs:inputHidden id='creationDateTime' value='{@iCreationDateTime}'/>
  <gjs:inputHidden id='creationUserId' value='{@creationUserId}'/>
  <gjs:inputHidden id='oldType' value='{@changeRequestType}'/>
  <gjs:inputHidden id='oldStatus' value='{@status}'/>
  <gjs:inputHidden id='closeAction' value='{../@closeAction}'/>
  <xsl:apply-templates select='/ChangeRequestForm/changeRequestTypes/changeRequestType' mode='StatusComboBoxes'/>
  </gjs:frame>
  </div>



  <div id='divComments' class='tabPanelHidden' style='min-height: 370px;'>
  <gjs:frame>

  <!-- Set up form column widths -->
  <gjs:columnWidths>
    <gjs:column width='1'/>
    <gjs:column width='599'/>
  </gjs:columnWidths>

  <gjs:fields>
    <gjs:textarea
     id='comments'
     accesskey='C'
     rows='13'
     cols='90'
     value='{@comments}'
     onchange='Form.fnChanged(); fnChangeComments()'
     readonly='0'>
     <hint>Enter additional comments relating to this change request here</hint>
    </gjs:textarea>
  </gjs:fields>
  </gjs:frame>

  <gjs:frame>

  <!-- Set up form column widths -->
  <gjs:columnWidths>
    <gjs:column width='120'/>
    <gjs:column width='480'/>
  </gjs:columnWidths>

  <gjs:fields>
    <gjs:input
     id='chcuser'
     width='100'
     value='{@creationUserId}'
     readonly='1'>
      <label>Creation user ID</label>
    </gjs:input>

    <gjs:input
     id='chcdate'
     width='100'
     value='{@creationDateTime}'
     readonly='1'>
      <label>Creation date /time</label>
    </gjs:input>

    <gjs:input
     id='chauser'
     width='100'
     value='{@lastModifiedUserId}'
     readonly='1'>
      <label>Last modified user ID</label>
    </gjs:input>

    <gjs:input
     id='chadate'
     width='100'
     value='{@lastModifiedDateTime}'
     readonly='1'>
      <label>Last modified date /time</label>
    </gjs:input>

  </gjs:fields>
  </gjs:frame>
  </div>

  <xsl:call-template name='customFrames' />

  <!-- Leave some space after the panels and before the buttons -->
  <table><tr><td height='6px'></td></tr></table>

</xsl:template>


<xsl:template match='changeRequestTypes'>
</xsl:template>

<xsl:template match='changeRequestTypes' mode="type">
  <item>
    <label></label>
    <value></value>
  </item>
  <xsl:apply-templates select="changeRequestType" mode="type"/>
</xsl:template>

<xsl:template match='changeRequestType' mode="type">
<item>
  <label><xsl:value-of select="concat(@changeRequestType,' - ',@description)" /></label>
  <value><xsl:value-of select="@changeRequestType" /></value>
</item>
</xsl:template>

<!-- Populate status list box with change request statii for current change request type -->
<xsl:template match='changeRequestStatus' mode="currentStatus">
<item>
  <label><xsl:value-of select="@status" /></label>
  <value><xsl:value-of select="@status" /></value>
</item>
</xsl:template>

<xsl:template match='/ChangeRequestForm/changeRequestTypes/changeRequestType' mode='StatusComboBoxes'>
  <select id='statusFor{@changeRequestType}' gjsValue='{@initialStatus}' style='display: none;'>
    <xsl:apply-templates select='changeRequestStatii/changeRequestStatus'>
      <xsl:sort select='@statusSequence' data-type='number'/>
    </xsl:apply-templates>
  </select>
</xsl:template>

<xsl:template match='changeRequestStatus'>
  <option value='{@status}'><xsl:value-of select='@status'/></option>
</xsl:template>


<xsl:template name='customTabs' />
<xsl:template name='customFrames' />

</xsl:stylesheet>

