<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:msxsl="urn:schemas-microsoft-com:xslt"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<!-- Information messages -->
<xsl:template match='/ServerLink/Information'>
  <gjs:form
    title='Object Properties'
    save='no'
    close='yes'
    delete='no'
    print='no'
    help='no'>
    <p class='caption' style='color: red'>
      <img src="vcmWarning.gif"/>&nbsp;&nbsp;
      <xsl:value-of select='@message'/>
    </p>
  </gjs:form>
</xsl:template>

<xsl:template match="Form">
  <xsl:apply-templates select="objectVersion"/>
</xsl:template>

<xsl:template match="objectVersion">
<gjs:form
 title='Deltanji Object Version Properties Maintenance'
 jsFile='vc870.js'
 onload='fnLoad();'
 save='{/Form/@save}'
 close='{/Form/@close}'
 delete='{/Form/@delete}'
 print='{/Form/@print}'
 help='{/Form/@help}'
 ok='{/Form/@ok}'
 cancel='{/Form/@cancel}'>

  <gjs:tabStrip>
    
    
    <gjs:tabStripTab
     id='tabObjectMaintenance'
     divId='divObjectMaintenance'
     height='200'
     accesskey='B'>
      O<u>b</u>ject Base
    </gjs:tabStripTab>
    <gjs:tabStripTab
     id='tabVariantMaintenance'
     divId='divVariantMaintenance'
     accesskey='R'>
      Va<u>r</u>iant
    </gjs:tabStripTab>
    <gjs:tabStripTab
     id='tabVersionMaintenance'
     divId='divVersionMaintenance'
     height='20'
     accesskey='V'>
      <u>V</u>ersion
    </gjs:tabStripTab>
    

    <!-- Include custom tabs here -->
    <xsl:call-template name='customTabs' />
  </gjs:tabStrip>

  <!-- The main object version maintenance panel -->
  <div id='divVersionMaintenance' class='visible' style='min-height:485px;'>
    <gjs:frame>
      <!-- Set up form column widths -->
      <gjs:columnWidths>
        <gjs:column width='130'/>
        <gjs:column width='350'/>
      </gjs:columnWidths>

      <gjs:fields>


    <gjs:input
     id='objVariVers'
     size='56'
     maxlength='60'
     value="{@object}/{@variant}.{@version}"
     readonly='1'>
      <label>Version</label>
     <hint>The version of this object</hint>
    </gjs:input>
    
    <gjs:input
     id='versionTitle'
     size='56'
     maxlength='200'
     value="{@description}"
     readonly='1'>
      <label>Version Title</label>
     <hint>The title of a version is that of the variant unless that is not defined, in which case it is the title of the base object</hint>
    </gjs:input>

    <gjs:textarea
     id='versionComment'
     accesskey='N'
     rows='12'
     cols='56'
     value='{@versionComment}'
     onchange='Form.fnChanged()'
     readonly='0'>
     <label>Version <u>n</u>otes</label>
     <hint>Free text comments specific to this version of this object</hint>
    </gjs:textarea>

    <gjs:input
     id='masterLocation'
     size='56'
     maxlength='60'
     value='{@masterLocation}'
     onchange='Form.fnChanged()'
     readonly='1'>
     <label>Master location</label>
     <hint>The location that contains the master copy of this version</hint>
    </gjs:input>

    <!-- NB for a merge-product the *original* checkout version is recorded in a secondary field -->
    <xsl:choose>
      <xsl:when test='@mergedObjectVersion=""'>
        <gjs:input
         id='predecessorObjectVersion'
         size='56'
         maxlength='60'
         value='{@predecessorObjectVersion}'
         readonly='1'>
          <label>Parent version</label>
         <hint>The version from which this version was initially created</hint>
        </gjs:input>

        <gjs:input
         id='mergedObjectVersion'
         size='56'
         maxlength='60'
         value=''
         readonly='1'>
          <label>Merged version</label>
         <hint>Not the product of a merge</hint>
        </gjs:input>
      </xsl:when>
      <xsl:otherwise>
        <gjs:input
         id='mergedObjectVersion'
         size='56'
         maxlength='60'
         value='{@mergedObjectVersion}'
         readonly='1'>
          <label>Parent version</label>
         <hint>The version from which this version was initially created</hint>
        </gjs:input>

        <gjs:input
         id='predecessorObjectVersion'
         size='56'
         maxlength='60'
         value='{@predecessorObjectVersion}'
         readonly='1'>
          <label>Merged version</label>
         <hint>The version from another branch that was merged into this version</hint>
        </gjs:input>
      </xsl:otherwise>
    </xsl:choose>

    
    <tr title='A list of all versions that have been created from this version'>
      <gjs:caption for='successor'>
        <label>
          Successor(s)
        </label>
      </gjs:caption>
      <td>
        <div class='gridTableOuter' style='min-height: 30px; width: 379px;'>
          <table class='formLayoutTable'>
          </table>
          <div class='gridTableInner' style='height: 30px; width:377px;' id='divSuccessor'>
            <table class='formLayoutTable'>
              <xsl:apply-templates select="/Form/objectVersion/objectVersionSuccessors/objectVersion" mode='list1' />
	    </table>
          </div>
        </div>
      </td>
    </tr>


    <gjs:input
     id='creationUserId'
     size='30'
     maxlength='29'
     value='{@creationUserId}'
     readonly='1'>
      <label>Creation user ID</label>
     <hint>The ID of the user who created this version (normally by performing a check-out)</hint>
    </gjs:input>

    <xsl:variable name='dateFormatted'>
      <xsl:choose>
	<xsl:when test=' /Form/user/@locale ="US"'>
	  <xsl:value-of select="translate('Mm/Dd/CcYy','CcYyMmDd',@creationDate)"/>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:value-of select="translate('Dd/Mm/CcYy','CcYyMmDd',@creationDate)"/>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <gjs:input
     id='displayCreationDate'
     size='30'
     maxlength='29'
     value='{$dateFormatted}'
     readonly='1'>
     <label>Creation date</label> 
     <hint>The date when this version was created (normally by a check-out or merge operation)</hint>
    </gjs:input>


    <gjs:list1
         id='allChangeRequest'
         width='379'
         size='2'
         accesskey='R'
	 readonly='1'>
          <label>Change request(s)</label>
          <hint>The change requests this object version is linked to</hint>
          <xsl:apply-templates select="/Form/allChangeRequests/changeRequest" mode='list1'/>
    </gjs:list1>
   

    <gjs:list1
         id='primaryChangeRequest'
         width='379'
         size='1'
         accesskey='R'
	 readonly='0'
         value='{/Form/primChangeRequest/changeRequest/@chref}'>
          <label>Primary change <u>r</u>equest</label>
          <hint>The change request that is designated as the primary change request</hint>
          <xsl:apply-templates select="/Form/primChangeRequest/changeRequest"  mode='list1'>
          </xsl:apply-templates>
          <xsl:apply-templates      select="/Form/allChangeRequests/changeRequest[not(/Form/primChangeRequest/changeRequest/@chref=@chref)]" mode='list1'>
          </xsl:apply-templates>
    </gjs:list1>


  </gjs:fields>

  <gjs:inputHidden id='revision' value='{@revision}'/>
  <gjs:inputHidden id='creationDateTime' value='{@creationDate}'/>
  <gjs:inputHidden id='statusDate' value='{@statusDate}'/>
  <gjs:inputHidden id='vers' value='{@version}'/>
  <gjs:inputHidden id='vari' value='{@variant}'/>
  <gjs:inputHidden id='obj' value='{@obj}'/>
  <gjs:inputHidden id='oldobj' value='{@obj}'/>
  </gjs:frame>
  </div>



  <div id='divVariantMaintenance' class='hidden' style='min-height:485px'>
  <gjs:frame>

  <!-- Set up form column widths -->
  <gjs:columnWidths>
    <gjs:column width='120'/>
        <gjs:column width='380'/>
  </gjs:columnWidths>

  <gjs:fields>

    <gjs:input
     id='objVari'
     size='56'
     maxlength='60'
     value="{@object}/{@variant}"
     onchange='Form.fnChanged()'
     readonly='1'>
     <label>Variant</label>
     <hint>The variant of this object</hint>
    </gjs:input>    

    <gjs:input
     id='variantDescription'
     accesskey='E'
     size='56'
     maxlength='200'
     value='{@variantDescription}'
     onchange='Form.fnChanged()'
     readonly='0'>
     <label>Variant titl<u>e</u></label>
     <hint>The title of a variant defaults to that of the base object.  However, a different title can be entered for each variant if required.</hint>
    </gjs:input>

    <gjs:textarea
     id='variantComment'
     accesskey='N'
     rows='14'
     cols='56'
     value='{@variantComment}'
     onchange='Form.fnChanged()'
     readonly='0'>
     <label>Variant <u>n</u>otes</label>
     <hint>Free text comments specific to this variant of this object</hint>
    </gjs:textarea>

   <tr>
      <td height='16'></td>
   </tr>
 
    <tr>
      <gjs:caption for='system' accesskey='Y'>
        <label>
          S<u>y</u>stems
        </label>
      </gjs:caption>
      <td>
        <div class='gridTableOuter' style='min-height: 150px; width: 360px;'>
          <table class='formLayoutTable'>
          </table>
          <div class='gridTableInner' style='height: 150px;' id='divSystems'>
            <table class='formLayoutTable'>
              <tr>
                <gjs:column width='20'/>
                <gjs:column width='320'/>
              </tr>
              <xsl:apply-templates select="/Form/systemsForObjectVariant/system" mode='grid'>
                <xsl:with-param name='inSystem' select='"Y"'/>
              </xsl:apply-templates>
              <xsl:if test='/Form/@editSystems!="disabled"'>
                <tr class='row'>
                <td style='width: 20px;'></td>
								<td>---- other available systems ----</td>
								</tr>
                <xsl:apply-templates select="/Form/systems/system[not(/Form/systemsForObjectVariant/system/@system=@system) and @withdrawn='0']" mode='grid'>
                  <xsl:with-param name='inSystem' select='"N"'/>
                </xsl:apply-templates>
              </xsl:if>
            </table>
          </div>
        </div>
      </td>
    </tr>


  </gjs:fields>
  </gjs:frame>
  </div>

  <div id='divObjectMaintenance' class='hidden' style='min-height:485px'>
  <gjs:frame>


  <!-- Set up form column widths -->
  <gjs:columnWidths>
    <gjs:column width='120'/>
    <gjs:column width='380'/>
  </gjs:columnWidths>

  <gjs:fields>

  <gjs:input
     id='object'
     size='56'
     maxlength='60'
     value='{@object}'
     onchange='Form.fnChanged()'
     readonly='1'>
     <label>Object base</label>
     <hint>The name of this base object</hint>
   </gjs:input>


  <gjs:input
     id='objectDescription'
     size='56'
     maxlength='200'
     value='{@objectDescription}'
     onchange='Form.fnChanged()'
     readonly='0'
     accesskey='E'>
     <label>Bas<u>e</u> title</label>
     <hint>The title of this base object</hint>
  </gjs:input>


  <gjs:textarea
     id='objectComment'
     accesskey='N'
     rows='24'
     cols='56'
     value='{@objectComment}'
     onchange='Form.fnChanged()'
     readonly='0'>
     <label>Base <u>n</u>otes</label>
     <hint>Free text comments about this base object</hint>
  </gjs:textarea>


  </gjs:fields>
  </gjs:frame>
  </div>

  <xsl:call-template name='customFrames' />

  <!-- Leave some space after the panels and before the buttons -->
  <table><tr><td height='6px'></td></tr></table>

</gjs:form>
</xsl:template>

<xsl:template name='customTabs' />
<xsl:template name='customFrames' />

<xsl:template match='system' mode="grid">
  <xsl:param name='inSystem'/>
  <tr 
   class='row'>
    <xsl:choose>
      <xsl:when test='/Form/@editSystems="disabled"'>
		    <xsl:attribute name='title'>Object is a member of this system. You do not have permission to change system membership.</xsl:attribute>  
		  </xsl:when>
		  <xsl:otherwise>
		    <xsl:attribute name='title'>When checked, object is a member of this system</xsl:attribute>  
		  </xsl:otherwise>
		</xsl:choose>
    <td style='padding-right: 5px;'>
      <input 
       type='checkbox'
       id='system'
       accesskey='y'
       onclick='Form.fnChanged()'
       value='{@system}'>
		    <xsl:if test='/Form/@editSystems="disabled"'>
		      <xsl:attribute name='disabled'/>  
		    </xsl:if>
        <xsl:if test='$inSystem="Y"'>
          <xsl:attribute name='checked'>checked</xsl:attribute>
        </xsl:if>
      </input>
    </td>
    <td>
      <xsl:if test='@withdrawn="1"'>
        <xsl:attribute name='style'>text-decoration: line-through;</xsl:attribute>
        <xsl:attribute name='title'>System has been withdrawn from use</xsl:attribute>
      </xsl:if>
      <xsl:value-of select='@system'/>
    </td>
  </tr>
</xsl:template>

<xsl:template match='objectVersion' mode="list1">
<tr>
<td>
<item>
  <label><xsl:value-of select="@objectVersion" /></label>
  <value><xsl:value-of select="@objectVersion" /></value>
</item>
</td>
</tr>
</xsl:template>


<xsl:template match='changeRequest' mode="list1">
<item>
  <label><xsl:value-of select="@chref" /></label>
  <value><xsl:value-of select="@chref" /></value>
</item>
</xsl:template>



</xsl:stylesheet>
