<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:variable name='readonly'>
    <xsl:choose>
      <xsl:when test='/Form/@method="view"'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>
  <gjs:form
   title='Physical Address'
   width='520'
   jsFile='vc271.js'
   onload='fnLoad();'
   save='{/Form/@save}'
   close='{/Form/@close}'
   delete='{/Form/@delete}'
   print='{/Form/@print}'
   help='{/Form/@help}'
   ok='{/Form/@ok}'
   cancel='{/Form/@cancel}'>

    <gjs:information>
      Advanced properties can be configured for each physical address which has been set up using in the location file.&nbsp; Each physical address may have multiple storage formats and advanced properties are configured individually for these.
      <xsl:choose>
        <xsl:when test='/Form/physicalLocation[1]/@genByKey!=""'>
          This record cannot be amended because it was derived from the <xsl:value-of select='/Form/physicalLocation[1]/@genByKey'/> template.
        </xsl:when>
        <xsl:when test='$readonly=1'>
          NOTE: Use of this feature is limited on your edition of Deltanji.
        </xsl:when>
        <xsl:otherwise>
          Templates can be defined by using {variable} notation in the key field.
        </xsl:otherwise>
      </xsl:choose>
    </gjs:information>

  <gjs:frame>
  <!-- Set up frame column widths -->
  <gjs:columnWidths>
    <gjs:column width='120'/>
    <gjs:column width='400'/>
  </gjs:columnWidths>

  <gjs:fields>

    <gjs:input
     id='physicalAddress'
     accesskey='A'
     size='50'
     maxlength='400'
     value='{/Form/physicalLocation[1]/@physicalAddress}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
       <label>Physical <u>a</u>ddress</label>
       <hint>Address of this physical location</hint>
    </gjs:input>

    <gjs:textarea
     id='description'
     accesskey='E'
     rows='3'
     cols='40'
     value='{/Form/physicalLocation[1]/@description}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label>D<u>e</u>scription</label>
     <hint>Description of this address</hint>
    </gjs:textarea>


    <gjs:inputHidden id='oldPhysicalAddress' value='{/Form/physicalLocation[1]/@physicalAddress}'/>


    <!-- Include dummy copy of storage fields here to ensure that there is always more than one
         instance of each field, even when there is only one storage format for the address.
         This has the result of making the storageFormat fields into an array so that they can
         be processed in a consistent manner in the save code. -->
    <gjs:inputHidden id='physicalLocation' value='gaga'/>
    <gjs:inputHidden id='revision' value='gaga'/>
    <gjs:inputHidden id='storageFormat' value='gaga'/>
    <gjs:inputHidden id='multiVersion' value='gaga'/>
    <gjs:inputHidden id='locationType' value='gaga'/>
    <gjs:inputHidden id='dependencyCheck' value='gaga'/>


  </gjs:fields>

  </gjs:frame>
    <gjs:tabStrip>

      <xsl:apply-templates select='/Form/physicalLocation' mode='tabStrip'/>

    </gjs:tabStrip>



    <xsl:apply-templates select='/Form/physicalLocation' mode='formFields'>
      <xsl:with-param name='readonly' select='$readonly'/>
    </xsl:apply-templates>

  <!-- Leave some space after the panels and before the buttons -->
  <table><tr><td height='6px'></td></tr></table>

  </gjs:form>
</xsl:template>



<xsl:template match="physicalLocation" mode="tabStrip">
    <gjs:tabStripTab
     id='tab{position()}'
     divId='div{@storageFormat}'>
      <xsl:value-of select='@storageFormat'/>
    </gjs:tabStripTab>
</xsl:template>




<xsl:template match="physicalLocation" mode='formFields'>
  <xsl:param name='readonly'/>

<div id='div{@storageFormat}' style='height: 290'>
  <xsl:choose>
    <xsl:when test='position()=1'>
      <xsl:attribute name='class'>tabPanelVisible</xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
      <xsl:attribute name='class'>tabPanelHidden</xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
  <gjs:frame>
  <!-- Set up frame column widths -->
  <gjs:columnWidths>
    <gjs:column width='135'/>
    <gjs:column width='300'/>
  </gjs:columnWidths>

  <gjs:fields>

    <gjs:inputHidden id='revision' value='{@revision}'/>
    <gjs:inputHidden id='storageFormat' value='{@storageFormat}'/>

    <gjs:input
     id='physicalLocation'
     size='45'
     maxlength='45'
     value='{@physicalLocation}'
     onchange='Form.fnChanged()'
     readonly='1'>
     <label>Physical location</label>
    </gjs:input>

    <tr>
      <td height='16'></td>
    </tr>

    <tr>
      <td></td>
      <td>
        <table class='formLayoutTable'>
              <tr>
                <gjs:column width='5'/>
                <gjs:column width='190'/>
                <gjs:column width='95'/>
              </tr>
              <tr>
                <td height='20'></td>
                <gjs:caption><label>Location</label></gjs:caption>
                <gjs:caption><label>Component mask</label></gjs:caption>
              </tr>            
        </table>
      </td>
    </tr>
    <tr>
      <gjs:caption for='divLocationsMappedToHere' accesskey='U'>
        <label>Locations mapped <br/>to this address</label>
      </gjs:caption>
      <td>
        <div class='gridTableOuter' style='min-height: 90px;'>
          <table class='formLayoutTable'>
          </table>
          <div class='gridTableInner' style='height: 90px;' id='divLocationsMappedToHere'>
            <table class='formLayoutTable'>
              <tr>
                <gjs:column width='2'/>
                <gjs:column width='191'/>
                <gjs:column width='95'/>
              </tr>

              <xsl:variable name='physicalLocation'><xsl:value-of select='@physicalLocation'/></xsl:variable>
              <xsl:apply-templates 
               select='locations/location/componentMasks/componentMask[@physicalLocation=$physicalLocation]'
               mode='grid'/>
            </table>
          </div>
        </div>
      </td>
    </tr>

    <tr>
      <td height='16'></td>
    </tr>

    <gjs:list1
     id='multiVersion'
     accesskey='V'
     width='200'
     value='{@multiVersion}'
     onchange='Form.fnChanged()'>
      <xsl:if test='$readonly="1"'>
        <xsl:attribute name='disabled'/>  
      </xsl:if>
      <label>Single /multi-<u>v</u>ersion</label>
      <hint>Specify whether you want to store one or multiple versions of objects in this location.  Note, some physical locations cannot hold multiple versions of objects.</hint>
      <item>
        <label>Single Version</label>
        <value>N</value>
      </item>
      <item>
        <label>Multi-Version</label>
        <value>Y</value>
      </item>
    </gjs:list1>

    <gjs:list1
     id='locationType'
     accesskey='L'
     width='200'
     value='{@locationType}'
     onchange='Form.fnChanged()'>
      <xsl:if test='$readonly="1"'>
        <xsl:attribute name='disabled'/>  
      </xsl:if>
      <label>Contro<u>ll</u>ed /uncontrolled</label>
      <hint>Controlled locations are managed tightly by Deltanji. Uncontrolled locations are less tightly controlled. Specifically, unregistered components can be overwritten by transfers from other locations.</hint>
      <item>
        <label>Controlled</label>
        <value>C</value>
      </item>
      <item>
        <label>Uncontrolled</label>
        <value>U</value>
      </item>
    </gjs:list1>

    <gjs:list1
     id='dependencyCheck'
     accesskey='K'
     width='200'
     value='{@dependencyCheck}'
     onchange='Form.fnChanged()'>
      <xsl:if test='$readonly="1"'>
        <xsl:attribute name='disabled'/>  
      </xsl:if>
      <label>Dependency chec<u>k</u></label>
      <hint>Specify the type of checking to be performed when there is a dependency condition for this physical address.</hint>
      <item>
        <label>Best Available</label>
        <value>b</value>
      </item>
      <item>
        <label>Component Timestamp</label>
        <value>pd</value>
      </item>
      <item>
        <label>Physical Compare</label>
        <value>p</value>
      </item>
      <item>
        <label>Deltanji Internal Timestamp</label>
        <value>d</value>
      </item>
    </gjs:list1>

  </gjs:fields>

  </gjs:frame>
</div>
</xsl:template>

<xsl:template match='componentMask' mode='grid'>
  <tr>
    <td></td>
    <td>
      <input 
       type='text' 
       size='30'
       id='location' 
       name='location'
       readonly='true'
       value='{../../@location}' 
       class='inputDisabled' />
    </td>
    <td>
      <input 
       type='text' 
       size='10'
       id='componentMask' 
       name='componentMask' 
       readonly='true'
       value='{@componentMask}' 
       class='inputDisabled' />
    </td>
  </tr>
</xsl:template>



</xsl:stylesheet>
