<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:apply-templates select="user"/>
</xsl:template>

<xsl:template match="user">
  <xsl:variable name='solo'>
    <xsl:choose>
      <xsl:when test='/Form/parameters/@features &lt; 4'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>

<gjs:form
 title='User'
 width='550'
 jsFile='vc321.js'
 onload='fnLoad();'
 save='{/Form/@save}'
 close='{/Form/@close}'
 delete='{/Form/@delete}'
 print='{/Form/@print}'
 help='{/Form/@help}'
 ok='{/Form/@ok}'
 cancel='{/Form/@cancel}'>
  <xsl:if test='$solo=1'>
    <xsl:attribute name='delete'>no</xsl:attribute>
  </xsl:if>

  <gjs:information>
    For each application user, enter their account name as the User ID.&nbsp;
    A user authenticated with the host operating system will be able to access the application automatically.&nbsp;
    A user accessing it via an anonymous connection will be prompted for a User ID and password.&nbsp;
    <xsl:if test='$solo=1'>
      NOTE: Users cannot be added on your edition of Deltanji, and amendment is limited.
    </xsl:if>
  </gjs:information>
  
  <br/>

  <gjs:tabStrip>
    <gjs:tabStripTab
     id='tabUser'
     accesskey='T'
     divId='divUser'>
      Main De<u>t</u>ails
    </gjs:tabStripTab>
    <gjs:tabStripTab
     id='tabAdvanced'
     accesskey='V'
     divId='divAdvanced'>
      Ad<u>v</u>anced
    </gjs:tabStripTab>
  </gjs:tabStrip>
  
  <!-- The main user detail panel -->
  <div id='divUser' class='tabPanelVisible' style='height: 280px;'>
    <gjs:frame>
    <!-- Set up frame column widths -->
    <gjs:columnWidths>
      <gjs:column width='120'/>
      <gjs:column width='290'/>
    </gjs:columnWidths>
  
    <gjs:fields>
  
      <gjs:input
       id='user'
       accesskey='U'
       size='30'
       maxlength='30'
       value='{@user}'
       onchange='Form.fnChanged()'
       readonly='{$solo}'>
       <label><u>U</u>ser ID</label>
       <hint>Enter a users login account name</hint>
      </gjs:input>
  
  
      <gjs:input
       id='name'
       accesskey='N'
       size='40'
       maxlength='40'
       value='{@name}'
       readonly='{$solo}'>
       <label><u>N</u>ame</label>
       <hint>Enter the name of the user</hint>
      </gjs:input>
  
  
      <tr>
        <td height='16'></td>
      </tr>
      <tr>
        
        <gjs:caption><label>Alia<u>s</u>es</label></gjs:caption>
  
        <td>
          <div class='gridTableOuter' style='height: 49px;'>
            <table class='formLayoutTable' style='margin-left: 2px'>
                <tr>
                  <gjs:column width='175'/>
                </tr>           
            </table>
            <div class='gridTableInner' style='height: 49px;' id='divAliases'>
              <table class='formLayoutTable'>
                <tr>
                  <gjs:column width='175'/>
                </tr>
  
                <xsl:apply-templates select='/Form/user/aliases'/>
  
              </table>
            </div>
          </div>
        </td>
      </tr>
  
      <tr>
        <td height='16'></td>
      </tr>
  
  
      <gjs:input
       id='accessCodes'
       accesskey='A'
       size='40'
       maxlength='1000'
       value='{@accessCodes}'
       readonly='{$solo}'>
       <label><u>A</u>ccess rights</label>
       <hint>Enter a comma separated list of access rights for this user</hint>
      </gjs:input>
  
    <tr title='Enter a password.  Leave blank if integrated authentication is being used.'>
      <gjs:caption for='password1' accesskey='W'>
        <label>Pass<u>w</u>ord</label>
      </gjs:caption>
      <td>
        <input 
         type='password' 
         size='30'
         maxlength='30' 
         id='password1' 
         name='password1' 
         value='{@password}' 
         class='input'
         readonly='{/Form/parameters/@disallowPassword}' 
         onChange='Form.fnChanged()'/>
      </td>
    </tr>
  
    <tr title='Re-enter the password to confirm that it has been typed correctly'>
      <gjs:caption for='password2' accesskey='R'>
        <label><u>R</u>e-enter password</label>
      </gjs:caption>
      <td>
        <input 
         type='password' 
         size='30'
         maxlength='30' 
         id='password2' 
         name='password2' 
         value='{@password}' 
         class='input' 
         readonly='{/Form/parameters/@disallowPassword}' 
         onChange='Form.fnChanged()'/>
      </td>
    </tr>
  
      <gjs:checkbox
       id='cancelAuthority'
       accesskey='E'
       checked='{number(@cancelAuthority="Y")}'
       readonly='{$solo}'>
        <label>Canc<u>e</u>l all checkouts?</label>
        <hint>User is permitted to cancel checkouts done by others, not only their own</hint>
      </gjs:checkbox>
  
      <gjs:list1
       id='locale'
       accesskey='F'
       width='100'
       value='{@locale}'
       onchange='Form.fnChanged()'
       readonly='0'>
        <label>Date <u>f</u>ormat</label>
        <hint>Select the date format for this user</hint>
        <item>
          <label>mm/dd/yyyy</label>
          <value>US</value>
        </item>
        <item>
          <label>dd/mm/yyyy</label>
          <value>EUROPE</value>
        </item>
      </gjs:list1>
  
      <xsl:choose>
        <xsl:when test='/Form/parameters/@namedUsers="0" or /Form/parameters/@concurrentUsers="0"'>
          <gjs:inputHidden id='licenseType' value='{@licenseType}'/>
        </xsl:when>
        <xsl:otherwise>
          <gjs:list1
           id='licenseType'
           accesskey='T'
           width='100'
           value='{@licenseType}'
           onchange='Form.fnChanged()'
           readonly='0'>
            <label>License <u>t</u>ype</label>
            <hint>Select the type of license this user requires</hint>
            <item>
              <label>Named</label>
              <value>N</value>
            </item>
            <item>
              <label>Concurrent</label>
              <value>C</value>
            </item>
          </gjs:list1>
        </xsl:otherwise>
      </xsl:choose>
  
    </gjs:fields>
  
    <gjs:inputHidden id='revision' value='{@revision}'/>
    <gjs:inputHidden id='oldUser' value='{@user}'/>
  
    </gjs:frame>
  </div>

  <!-- The Advanced panel -->
  <div id='divAdvanced' class='tabPanelHidden' style='height: 280px;'>
    <gjs:frame>
  
      <!-- Set up form column widths -->
      <gjs:columnWidths>
        <gjs:column width='120'/>
        <gjs:column width='320'/>
      </gjs:columnWidths>

      <gjs:fields>
        <tr>
          <gjs:caption>
            <label>
              Menu overrides
            </label>
          </gjs:caption>
          <td>
          <div class='gridTableOuter' style='min-height: 230px;'>
            <table class='formLayoutTable' style='margin-left: 2px'>
                <tr>
                  <gjs:column width='150'/>
                  <gjs:column width='140'/>
                </tr>
                <tr>
                  <gjs:caption><label><u>M</u>enu</label></gjs:caption>
                  <gjs:caption><label><u>O</u>verride</label></gjs:caption>
                </tr>            
            </table>
            <div class='gridTableInner' style='height: 230px;' id='divOverrides'>
              <table class='formLayoutTable'>
                <tr>
                  <gjs:column width='150'/>
                  <gjs:column width='140'/>
                </tr>
  
                <xsl:apply-templates select='/Form/user/menus'>
                </xsl:apply-templates>
  
              </table>
            </div>
          </div>
          </td>
        </tr>
      </gjs:fields>
  
    </gjs:frame>
  </div>
  
  <!-- Leave some space after the panels and before the buttons -->
  <table><tr><td height='6px'></td></tr></table>


</gjs:form>
</xsl:template>

<xsl:template match='/Form/user/aliases'>
  <xsl:variable name='numberOfDisplayRows' select='"2"'/>
  <xsl:variable name='numberOfDataRows' select='count(/Form/user/aliases/alias)'/>

  <!-- First row is a hidden row that is a template for new rows -->
  <xsl:call-template name='alias'>
    <xsl:with-param name='display' select='"0"'/>
    <xsl:with-param name='lastRow' select='"1"'/> <!-- sic -->
  </xsl:call-template>

  <!-- Next we render any data rows -->
  <xsl:apply-templates select='/Form/user/aliases/alias' mode='grid'>
    <xsl:with-param name='lastRow' select='"0"'/>
  </xsl:apply-templates>

  <!-- Now some empty rows to make sure the display window is full -->
  <xsl:call-template name='empty-rows'>
    <xsl:with-param name='n' select='number($numberOfDisplayRows)-number($numberOfDataRows)-1'/>
  </xsl:call-template>

  <!-- Finally the last row which, when filled, will generate a new row from the template -->
  <xsl:call-template name='alias'>
    <xsl:with-param name='lastRow' select='"1"'/>
  </xsl:call-template>
</xsl:template>


<!-- Generate n empty-rows -->
<xsl:template name="empty-rows">
  <xsl:param name="n"/>

  <xsl:if test="number($n) > 0">
    <xsl:call-template name='alias'>
      <xsl:with-param name='lastRow' select='"0"'/>
    </xsl:call-template>
    <!-- Call self recursively with n-1 rows -->
    <xsl:call-template name="empty-rows">
      <xsl:with-param name="n" select="number($n) - 1"/>
    </xsl:call-template>
  </xsl:if>

</xsl:template>


<xsl:template match='/Form/user/aliases/alias' name='alias' mode="grid">
  <xsl:param name='display' select='"1"'/>
  <xsl:param name='lastRow' select='"0"'/>
  <tr 
   title='If this user authenticates to the host environment under a different name, enter that name here'
   gjsLastRow='{$lastRow}'>
    <xsl:if test='$display="0"'>
      <xsl:attribute name='style'>display: none;</xsl:attribute>  
    </xsl:if>
    <td>
      <input 
       type='text' 
			 size='30'
			 maxlength='30'
       name='alias' 
       value='{@alias}' 
       class='input' 
       onkeypress='Form.fnRowChanged(this.parentNode.parentNode)'
       onchange='Form.fnRowChanged(this.parentNode.parentNode)'/>
    </td>
  </tr>
</xsl:template>


<xsl:template match='/Form/user/menus'>
  <xsl:variable name='numberOfDisplayRows' select='"1"'/>
  <xsl:variable name='numberOfDataRows' select='count(/Form/user/menus/menu)'/>

  <!-- First row is a hidden row that is a template for new rows -->
  <xsl:call-template name='menu'>
    <xsl:with-param name='display' select='"0"'/>
    <xsl:with-param name='lastRow' select='"1"'/> <!-- sic -->
  </xsl:call-template>

  <!-- Next we render any data rows -->
  <xsl:apply-templates select='/Form/user/menus/menu' mode='grid'>
    <xsl:with-param name='lastRow' select='"0"'/>
  </xsl:apply-templates>

  <!-- Now some empty rows to make sure the display window is full -->
  <xsl:call-template name='empty-rows2'>
    <xsl:with-param name='n' select='number($numberOfDisplayRows)-number($numberOfDataRows)-1'/>
  </xsl:call-template>

  <!-- Finally the last row which, when filled, will generate a new row from the template -->
  <xsl:call-template name='menu'>
    <xsl:with-param name='lastRow' select='"1"'/>
  </xsl:call-template>
</xsl:template>


<!-- Generate n empty-rows -->
<xsl:template name="empty-rows2">
  <xsl:param name="n"/>

  <xsl:if test="number($n) > 0">
    <xsl:call-template name='menu'>
      <xsl:with-param name='lastRow' select='"0"'/>
    </xsl:call-template>
    <!-- Call self recursively with n-1 rows -->
    <xsl:call-template name="empty-rows2">
      <xsl:with-param name="n" select="number($n) - 1"/>
    </xsl:call-template>
  </xsl:if>

</xsl:template>


<xsl:template match='/Form/user/menus/menu' name='menu' mode="grid">
  <xsl:param name='display' select='"1"'/>
  <xsl:param name='lastRow' select='"0"'/>
  <tr 
   title='Override menu to use for this user'
   gjsLastRow='{$lastRow}'>
    <xsl:if test='$display="0"'>
      <xsl:attribute name='style'>display: none;</xsl:attribute>  
    </xsl:if>
    <td>
      <table>
        <gjs:list1
         name='menu'
         accesskey='M'
         width='140'
         value='{@menu}'
         onchange='Form.fnRowChanged(this.parentNode.parentNode.parentNode.parentNode.parentNode.parentNode)'>
					<hint>Menu that is to be overridden for this user</hint>
					<item>
						<label></label>
						<value></value>
					</item>
					<xsl:apply-templates select='/Form/menus/menu' mode='list1' />
        </gjs:list1>
      </table>
    </td>
    <td>
      <table>
        <gjs:list1
         name='overrideMenu'
         accesskey='O'
         width='140'
         value='{@overrideMenu}'
         onchange='Form.fnRowChanged(this.parentNode.parentNode.parentNode.parentNode.parentNode.parentNode)'>
					<hint>Menu to be presented to this user instead</hint>
					<item>
						<label></label>
						<value></value>
					</item>
					<xsl:apply-templates select='/Form/menus/menu' mode='list1' />
        </gjs:list1>
      </table>
    </td>
  </tr>
</xsl:template>

<!-- Menus list boxes -->
<xsl:template match='/Form/menus/menu' mode='list1'>
<item>
  <label><xsl:value-of select="@menu" /></label>
  <value><xsl:value-of select="@menu" /></value>
</item>
</xsl:template>

</xsl:stylesheet>
