<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">


<xsl:include href='gjsForm.xsl'/>


<xsl:template match="Form">
  <xsl:variable name='enterprise'>
    <xsl:choose>
      <xsl:when test='/Form/parameters/@features &gt; 6'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='variable'>
    <xsl:choose>
      <xsl:when test='@method="copy"'></xsl:when>
      <xsl:otherwise><xsl:value-of select='variable/@variable' /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='revision'>
    <xsl:choose>
      <xsl:when test='@method="copy"'></xsl:when>
      <xsl:otherwise><xsl:value-of select='variable/@revision' /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>


  <gjs:form
   save="{@save}"
   close="{@close}" 
   delete="no" 
   print="{@print}" 
   help="{@help}" 
   ok="{@ok}" 
   cancel="{@cancel}"
   title='Variable'
   jsFile='Variable_Details.js'
   onload='frmMain.variable.focus()'>
    <xsl:if test='(@method!="copy") and ($enterprise!=0)'>
      <xsl:attribute name='delete'><xsl:value-of select='@delete' /></xsl:attribute>
    </xsl:if>

    <gjs:information>
      <xsl:if test='@method="copy"'>You are creating a copy of the definition of variable '<xsl:value-of select='variable/@variable'/>'.&nbsp;</xsl:if>
     Variables are fundamental to the creation of template definitions.&nbsp; A template definition
		 is a definition (e.g. of a Location or a Transfer Route) in which variables appear in fields
		 of the definition, enclosed in curly braces, for example {myVar}.&nbsp; When a template definition
		 is saved, regular definitions are generated by enumerating all the values defined for each of
		 the variables used by the template. 
      <xsl:if test='$enterprise=0'>
        NOTE: Use of this feature is limited on your edition of Deltanji.
      </xsl:if>
    </gjs:information>

    <div id='divVariable' class='visible'>
      <gjs:frame>
        <!-- Set up frame column widths -->
        <gjs:columnWidths>
          <gjs:column width='100'/>
          <gjs:column width='380'/>
        </gjs:columnWidths>

        <gjs:fields>

          <gjs:input
           id='variable'
           accesskey='V'
           size='20'
           maxlength='20'
           value='{$variable}'>
			      <xsl:if test='$variable!="" or $enterprise=0'>
			        <xsl:attribute name='readonly'>1</xsl:attribute>
			      </xsl:if>
            <label><u>V</u>ariable</label>
            <hint>Enter a name for the variable. Only alphanumeric characters are permitted.</hint>
          </gjs:input>

          <gjs:input
           id='description'
           accesskey='E'
           size='60'
           maxlength='200'
           value='{variable/@description}'>
			      <xsl:if test='$enterprise=0'>
			        <xsl:attribute name='readonly'>1</xsl:attribute>
			      </xsl:if>
            <label>D<u>e</u>scription</label>
            <hint>Enter a free text description of this variable</hint>
          </gjs:input>

          <tr>
            <td height='16'></td>
          </tr>

          <tr>
            <td colspan='2'>
              <table class='formLayoutTable' border='0'>
                <tr>
                  <gjs:column width='5'/>
                  <gjs:column width='275'/>
                  <gjs:column width='235'/>
                </tr>
                <tr>
                  <td height='16'></td>
                  <gjs:caption><label>V<u>a</u>lue</label></gjs:caption>
                  <gjs:caption><label><u>N</u>ote</label></gjs:caption>
                </tr>
              </table>
            </td>
          </tr>
          <tr>
            <td colspan='2'>
              <div class='gridTableOuter' style='height: 195px; min-width: 550px;'>
                <table class='formLayoutTable'>
                </table>
                <div class='gridTableInner' style='height: 195px;' id='divValues'>
                  <table class='formLayoutTable'>
                    <tr>
                      <gjs:column width='5'/>
                      <gjs:column width='255'/>
                      <gjs:column width='235'/>
                    </tr>

                    <xsl:apply-templates select='variable/values'/>

                  </table>
                </div>
              </div>
            </td>
          </tr>

        </gjs:fields>

        <gjs:inputHidden id='revision' value='{$revision}'/>

      </gjs:frame>
    </div>
  </gjs:form>

</xsl:template>


<xsl:template match='/Form/variable/values'>
  <!-- First row is a hidden row that is a template for new rows -->
  <xsl:call-template name='value'>
    <xsl:with-param name='style' select='"display: none;"'/>
    <xsl:with-param name='lastRow' select='"1"'/> <!-- sic -->
  </xsl:call-template>

  <!-- Next we render any data rows -->
  <xsl:apply-templates select='value' mode='grid'>
    <xsl:with-param name='lastRow' select='"0"'/>
  </xsl:apply-templates>
  
<!-- Finally the last row which, when filled, will generate a new row from the template -->
  <xsl:call-template name='value'>
    <xsl:with-param name='lastRow' select='"1"'/>
  </xsl:call-template>
</xsl:template>


<xsl:template match='/Form/variable/values/value' name='value' mode="grid">
  <xsl:param name='style'/>
  <xsl:param name='lastRow'/>
  <tr 
   style='{$style}'
   gjsLastRow='{$lastRow}'>
    <td>
    </td>
    <td>
      <input 
       type='text' 
       size='38'
       maxlength='400' 
       name='varValue' 
       value='{@value}' 
       class='input'
       onChange='Form.fnRowChanged(this.parentNode.parentNode)'>
       <xsl:attribute name='title'>One of the set of values the variable takes. Each value can be composed of multiple elements separated by the ' character. Subsidiary elements are accessed by suffixing the same number of ' characters on the variable name within its enclosing braces, i.e. {var'} for the second element, {var''} for the third.</xsl:attribute>
      </input>
    </td>
    <td>
      <input 
       type='text' 
       size='32'
       maxlength='400' 
       name='note' 
       value='{@note}' 
       class='input' 
       title='Optional note about this value'
       onChange='Form.fnRowChanged(this.parentNode.parentNode)'>
      </input>
    </td>


  </tr>
</xsl:template>


</xsl:stylesheet>
