<?php
// SEARCH-INDEX.PHP //
// Input: $query = the search query
// Output: $results_json = json encoded array of document filenames and the total number of results (the first entry)
//
// ******* PROCEDURE ******* //
//
require 'porter_stemmer.php';

// Get query and limits
$query = addslashes($_POST['query']);
//
// Declare final array of results
$all_results_arr = array();
//
// Gets Phrase Queries (strings within double quotation marks) PQs, returning them and the rest of the query
$getpqs = GetPQs($query);
$pq_array = $getpqs['pq_array']; // ****PQs****
//
// Gets OWQs, returning them to an array
$owq_array = GetOWQs($getpqs['query']); // ****OWQs****
//
//Open lengths array file and copy to PHP array
$lengths_copy = file_get_contents('title_lengths.json', true);
$lengths_arr = json_decode($lengths_copy, true);
//
$titles_pq_array = PQQuery($pq_array, 'title_index');
foreach ($titles_pq_array as $titles_pq_doc => $titles_pq) {
	if (!array_key_exists($titles_pq_doc,$titles_pq_array)) {
		$all_results_arr[] = $titles_pq_doc;
	}
}
//
$bodies_pq_array = PQQuery($pq_array, 'body_index');
//Remove search results that have already been returned
foreach ($bodies_pq_array as $bodies_pq_doc => $bodies_pq) {
	if (array_key_exists($bodies_pq_doc,$titles_pq_array)) {
		unset($bodies_pq_array[$bodies_pq_doc]);
	}
	$all_results_arr[] = $bodies_pq_doc;
}

//
$titles_owq_array = OWQQuery($owq_array, 'title_index');
//Remove search results that have already been returned
foreach ($titles_owq_array as $titles_owq_doc => $titles_owq) {
	if (array_key_exists($titles_owq_doc,$titles_pq_array)) {
		unset($titles_owq_array[$titles_owq_doc]);
	}
	if (array_key_exists($titles_owq_doc,$bodies_pq_array)) {
		unset($titles_owq_array[$titles_owq_doc]);
	}
	$all_results_arr[] = $titles_owq_doc;
}
//
$bodies_owq_array = OWQQuery($owq_array, 'body_index');
foreach ($bodies_owq_array as $bodies_owq_doc => $bodies_owq) {
	if (array_key_exists($bodies_owq_doc,$titles_pq_array)) {
		unset($bodies_owq_array[$bodies_owq_doc]);
	}
	if (array_key_exists($bodies_owq_doc,$bodies_pq_array)) {
		unset($bodies_owq_array[$bodies_owq_doc]);
	}
	if (array_key_exists($bodies_owq_doc,$titles_owq_array)) {
		unset($bodies_owq_array[$bodies_owq_doc]);
	}
	$all_results_arr[] = $bodies_owq_doc;
}
$docs_copy = file_get_contents('docs.json', true);
$docs_arr = json_decode($docs_copy, true);
foreach ($all_results_arr as $ptr => $all_results) {
	$all_results_arr[$ptr] = $docs_arr[$all_results];
}
$json = json_encode($all_results_arr,true);
echo $json;
//
// ********** FUNCTIONS ********** //
//
function GetPQs($query) {
	// Finds all phrase queries in the query and returns them to an array. Then splits each of the words in the phrase query into one word queries.
	// End result is an array of phrase queries, each of which is an array of one word queries.
	$pq_array = array();
	$split_pq_array = array();
	$quot_offset = 0;
	$no_more_pqs = false;
	//
	while (!$no_more_pqs) {
		//
		$quot_1_pos = strpos($query,'"',$quot_offset);
		//
		if (isset($quot_1_pos)) { // If there is at least one quotation mark in the query
			//
			$quot_offset = $quot_1_pos + 1;
			$quot_2_pos = strpos($query,'"',$quot_offset);
			//
			if (!empty($quot_2_pos)) { // There must be a second quotation mark along the query for it to be a pq
				//
				$pq_st = $quot_1_pos + 1;
				$pq_len = $quot_2_pos - $pq_st;
				$pq_array[] = substr($query,$pq_st,$pq_len); // Add this PQ to the array of PQs
				//
				//Trim query to rid it of pq
				$beg_len = $pq_st - 1;
				$end_st = $quot_2_pos + 1;
				$query = substr($query,0,$beg_len) . substr($query,$end_st);
				$quot_offset = $quot_1_pos;
				//
			} else {
				//
				$no_more_pqs = true;
				//
			}
			//
		} else {
			//
			$no_more_pqs = true;
			//
		}
		//
	}
	//
	// Get rid of multiple spaces
	for ($i=0;$i<count($pq_array);$i++) {
		$pq_array[$i] = preg_replace('!\s+!', ' ', $pq_array[$i]);
	}
	//Splits each PQ string into an array of OWQs
	foreach ($pq_array as $pq) {
		$split_pq_array[] = GetOWQs($pq);
	}
	$return_array = array(
		"pq_array" => $split_pq_array,
		"query" => $query
	);
	return $return_array;
	//
}

function GetOWQs($s) {
	//
	$owq_array = array();
	$owq_array = explode(" ",$s);
	//
	// Empty each OWQ of any extra spaces any extra spacebar characters
	// Remove non-alphanumeric characters
	// Apply porter stemmer
	for ($i=0;$i<count($owq_array);$i++) {
		$owq_array[$i] = preg_replace("!\s+!", "", $owq_array[$i]);
		$owq_array[$i] = strtolower($owq_array[$i]);
		$owq_array[$i] = preg_replace("/[^A-Za-z0-9]/", "", $owq_array[$i]);
		$owq_array[$i] = PorterStemmer::Stem($owq_array[$i]);
		
	}
	//
	return $owq_array;
}

function PQQuery($pq_array, $index) {
	global $lengths_arr;
	$results_collector = array();
	$index_copy = file_get_contents($index . '.json', true);
	$index_arr = json_decode($index_copy, true);
	$inv_index = array();
	foreach ($pq_array as $pq) { // For Each Phrase
		//Creates an inverted array of all of the documents that contain all of the words in the phrase query
		foreach ($pq as $owq) { // For Each word in the phrase
			if (($owq != "") && (array_key_exists($owq,$index_arr))) { // If the word is in the index
				foreach ($index_arr[$owq] as $dockey => $doc) { // For each document that contains the word
					$inv_index[$dockey][$owq] = $doc; // Add the document to the inverted index as an entry containing the word and its positions
				}
			}
		}
		//Removes any document entries from the inverted index that do not contain all of the words in the phrase query
		foreach ($pq as $owq) { // For Each word in the phrase
			foreach ($inv_index as $dockey => $owq_arr) { // For each document in the inverted index
				if (!array_key_exists($owq, $owq_arr)) { // If the word does not exist in the document's entry in the inverted index
					unset($inv_index[$dockey]);	// Remove the document's entry from the inverted index
				}
			}
		}
		// Subtracts n from the positions of the nth word. This means that words that are in the same sequence in the document as they are in the phrase query will have the same position numbers. Doing an array_intersect on each entry will then give us the documents that contain the phrase query.
		foreach ($inv_index as $dockey => $owq_arr) {
			$owq_ptr = 0;
			foreach ($owq_arr as $owq => $pos_list) {
				foreach ($pos_list as $pos_no => $pos) {
					$inv_index[$dockey][$owq][$pos_no] = $pos - $owq_ptr;
				}
				$owq_ptr = $owq_ptr + 1;
			}
		}
		
		//Perform array_intersect to get the documents which contain the phrase query in its correct order
		foreach($inv_index as $dockey => $owq_arr) {
			//Get $highest_no_of_pos (highest number of word positions)
			$highest_no_of_pos = 0;
			foreach ($owq_arr as $owq => $pos_list) {
				if (count($pos_list) > $highest_no_of_pos) {
					$highest_no_of_pos = count($pos_list);
				}
			}
			$pos_arr = array();
			for ($i=0;$i<$highest_no_of_pos;$i++) {
				foreach ($owq_arr as $owq => $pos_list) {
					if (array_key_exists($i,$owq_arr[$owq])) {
						$pos_arr[] = $owq_arr[$owq][$i];
					} else {
						$i = $highest_no_of_pos;
					}
				}
				if (count(array_keys($pos_arr, $pos_arr[0])) == count($pos_arr)) {
					if (array_key_exists($dockey,$results_collector)) {
						$results_collector[$dockey] = $results_collector[$dockey] + 1;
					} else {
						$results_collector[$dockey] = 1;
					}
				}
			}
		}
	}
	arsort($results_collector); // Sort by highest score
	return $results_collector;
}

function OWQQuery($owq_array, $index) {
	global $lengths_arr;
	$results_collector = array();
	$index_copy = file_get_contents($index . '.json', true);
	$index_arr = json_decode($index_copy, true);
	foreach ($owq_array as $owq) {
		if (($owq != "") && (array_key_exists($owq,$index_arr))) {
			foreach ($index_arr[$owq] as $dockey => $doc) {
				$score = (10 * count($doc[0])) - $lengths_arr[$dockey];
				if (array_key_exists($dockey,$results_collector)) {
					$results_collector[$dockey] += $score;
				} else {
					$results_collector[$dockey] = $score;
				}
			}
		}
	}
	arsort($results_collector); // Sort by highest score
	return $results_collector;
}

?>
