<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet 
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

  <!-- Tree Control
       ============

      Import (do not include) gjsTree.xsl in an xsl template to generate a tree control.  Folder and Leaf 
      elements within the Rows element in the source document will get transformed into folders 
      and leaves in a tree.
      
      Override any of the following named templates to provide custom behaviour:
        divMainHead          - provide row headings
        folderContent        - provide row content for a folder
        leafContent          - provide row content for a leaf
        tableAttributes      - provide custom attributes for the table
        folderRowAttributes  - provide custom attributes for a folder row
        leafRowAttributes    - provide custom attribues for a leaf row
        subFolderMethod      - provide the name of the server-side method that will generate a sub-folder
        subFolderArguments   - provide a +delimiter+ delimited list of arguments for the server-side method
      
      Override the following templates if required:
       /ServerLink/Rows      - for custom heading behaviour and logic (should then call gjs:tree)

      The following templates are public and can be called as required:
        gjs:tree             - Generate a tree
        gjs:treeMore         - Generate mores list for parents
        gjs:treeMoresMainHeading - Generate a series of blank more cells for column headings
        gjs:treeColumnHeading - Generate markup for a sortable column heading

  -->


  <!-- Global variable containing count of items -->
  <xsl:variable name='gjs:gCountIcons' select='count(/ServerLink/Rows/Folder|/ServerLink/Rows/Leaf)' />
  <xsl:variable name='gjs:gMaxItems' select='$gjs:gCountIcons&gt;=/ServerLink/Rows/@maxObjects and not(/ServerLink/Rows/@maxObjects="0")' />
  <xsl:variable name='gjs:resultTableBody' select='""'/>


  <!-- Override this template if you want to populate column headings etc -->
  <xsl:template match="/ServerLink/Rows">
    <div id='divMainHead'>
      <xsl:call-template name='divMainHead'/>
    </div>

    <xsl:call-template name='gjs:tree'/>

  </xsl:template>


  <!-- Public - Generate tree rows for each Folder and Leaf -->
  <xsl:template name='gjs:tree'>
    <!-- caller can optionally specify the id of the div where headings should be displayed; default is divMainHead -->
    <xsl:param name='divHeadingId' select='"divMainHead"' />
    
    <xsl:param name='divReferenceHeadingId' select='concat(/ServerLink/@runId,"_mainHead")' />
    <!-- display 'no items found' when there are no items; resultset or caller can override 'yes' default  -->
    <xsl:param name='noItemsFound'>
      <xsl:choose>
        <xsl:when test='/ServerLink/TreeParams/@noItemsFound'><xsl:value-of select='/ServerLink/TreeParams/@noItemsFound' /></xsl:when>
        <xsl:otherwise>yes</xsl:otherwise>
      </xsl:choose>
    </xsl:param> <!-- display 'no items found' when there are no items -->

    <xsl:variable name='resultTableId' select='concat(/ServerLink/@runId,"_table")' />

    <div id='divMainBody' gjsLoad='gjsTree.fnResizeColumns("{$resultTableId}","{$divReferenceHeadingId}")'>

      <!-- Generate hidden reference copy of column headings -->
      <div id='{$divReferenceHeadingId}' style='display: none'>
        <!-- Add the gjsDivHeadingId attribute only at the root level of the table -->
        <xsl:if test='/ServerLink/Rows/@mores = ""'>
          <xsl:attribute name='gjsDivHeadingId'><xsl:value-of select='$divHeadingId' /></xsl:attribute>
        </xsl:if>

        <xsl:call-template name='divMainHead' />
      </div>

      <table
       id='{$resultTableId}'
       gjsReferenceHeadingId='{$divReferenceHeadingId}'
       border='0'
       class='layoutTable'>

      <!-- Add custom table attributes -->
      <xsl:call-template name='tableAttributes'>
        <xsl:with-param name='tableId' select='/ServerLink/@runId'/>
      </xsl:call-template>

        <xsl:if test='$gjs:gMaxItems'>
          <tfoot>
            <tr class='treeRow'>

              <!-- Generate mores cells -->
              <xsl:call-template name='gjs:treeMores' />
              <xsl:call-template name='gjs:treeMoreCell'>
                <xsl:with-param name='more' select='"L"' />
              </xsl:call-template>

              <td><img src='vcmWarning_l.gif'/></td>
              <td colspan='99' style='color: red'>
                Maximum number of items (<xsl:value-of select='@maxObjects'/>) shown
              </td>
            </tr>
          </tfoot>
        </xsl:if>

        <xsl:choose>
          <xsl:when test='$gjs:gCountIcons=0 and $noItemsFound="yes"'>
            <tfoot>
              <tr class='treeRow'>
                
                <!-- Generate mores cells -->
                <xsl:call-template name='gjs:treeMores' />
                <xsl:call-template name='gjs:treeMoreCell'>
                  <xsl:with-param name='more' select='"L"' />
                </xsl:call-template>
                
                <td width='25' style='min-width:25px; max-width:25px; width:25px' align='center'><img src='vcmWarning_l.gif'/></td>
                <td colspan='99' style='color: red'>
                  No items found
                </td>
              </tr>
            </tfoot>
          </xsl:when>  
          <xsl:otherwise>
            
            <!-- This is the context set for the generated tree (affects position()=last() so watch out) -->
            <xsl:apply-templates select='HeadFolder|HeadLeaf|FootFolder|FootLeaf|Folder|Leaf' mode='gjsTree'/>
            
            
          </xsl:otherwise>
        </xsl:choose>

      </table>
    </div>

    <!-- Process deletions -->
    <xsl:if test='/ServerLink/Rows/Delete'>
      <div id='divRowDelete'>
        <xsl:apply-templates select='/ServerLink/Rows/Delete' mode='gjsDelete'/>
      </div>
    </xsl:if>

  </xsl:template>


  <!-- Identity template - copy content of Delete nodes verbatim -->
  <xsl:template match="/ServerLink/Rows/Delete" mode='gjsDelete'>
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" mode='gjsDelete'/>
    </xsl:copy>
  </xsl:template>


  <!-- Identity template - copy content of Delete nodes verbatim -->
  <xsl:template match="@*|node()" mode='gjsDelete'>
    <xsl:copy>
      <xsl:apply-templates select="@*|node()" mode='gjsDelete'/>
    </xsl:copy>
  </xsl:template>


  <xsl:template match="/ServerLink/Rows/Folder | /ServerLink/Rows/Leaf | /ServerLink/Rows/HeadFolder | /ServerLink/Rows/HeadLeaf | /ServerLink/Rows/FootFolder | /ServerLink/Rows/FootLeaf" mode='gjsTree'>

    <!-- Generate unique id for this Row - use runId to make it unique across multiple calls to the server -->
    <!-- It can be suffixed it with a descriptor (eg "main") to make as many different IDs as needed -->
    <xsl:variable name='rowId' select='concat(/ServerLink/@runId,"_",generate-id(),"_")'/>
    

    <xsl:choose>

      <!-- Body folder, there can be many, they are sortable -->
      <xsl:when test='name()="Folder"'>
        <tbody id='{$rowId}body' gjsRowId='{$rowId}' gjsTargetRowId='{rowUpdate/@rowId}'>
          <xsl:call-template name='gjs:folderContent'>
            <xsl:with-param name='rowId' select='$rowId' />
          </xsl:call-template>
        </tbody>
      </xsl:when>

      <!-- Body leaf, there can be many, they are sortable -->
      <xsl:when test='name()="Leaf"'>
        <tbody id='{$rowId}body' gjsRowId='{$rowId}' gjsTargetRowId='{rowUpdate/@rowId}'>
          <xsl:call-template name='gjs:leafContent'>
            <xsl:with-param name='rowId' select='$rowId' />
          </xsl:call-template>
        </tbody>
      </xsl:when>

      <!-- Header folder, there can only be one, not sorted -->
      <xsl:when test='name()="HeadFolder"'>
        <thead id='{$rowId}body' gjsRowId='{$rowId}' gjsTargetRowId='{rowUpdate/@rowId}'>
          <xsl:call-template name='gjs:folderContent'>
            <xsl:with-param name='rowId' select='$rowId' />
          </xsl:call-template>
        </thead>
      </xsl:when>

      <!-- Header leaf, there can only be one, not sorted -->
      <xsl:when test='name()="HeadLeaf"'>
        <thead id='{$rowId}body' gjsRowId='{$rowId}' gjsTargetRowId='{rowUpdate/@rowId}'>
          <xsl:call-template name='gjs:leafContent'>
            <xsl:with-param name='rowId' select='$rowId' />
          </xsl:call-template>
        </thead>
      </xsl:when>

      <!-- Footer folder, there can only be one, not sorted -->
      <xsl:when test='name()="FootFolder"'>
        <tfoot id='{$rowId}body' gjsRowId='{$rowId}' gjsTargetRowId='{rowUpdate/@rowId}'>
          <xsl:call-template name='gjs:folderContent'>
            <xsl:with-param name='rowId' select='$rowId' />
          </xsl:call-template>
        </tfoot>
      </xsl:when>

      <!-- Footer leaf, there can only be one, not sorted -->
      <xsl:when test='name()="FootLeaf"'>
        <tfoot id='{$rowId}body' gjsRowId='{$rowId}' gjsTargetRowId='{rowUpdate/@rowId}'>
          <xsl:call-template name='gjs:leafContent'>
            <xsl:with-param name='rowId' select='$rowId' />
          </xsl:call-template>
        </tfoot>
      </xsl:when>
    
    </xsl:choose>
    
  </xsl:template>


    


  <!-- The main control template for a +/- folder -->
  <xsl:template name='gjs:folderContent'>
    <xsl:param name='rowId' />

    <!-- lastRow is a boolean that indicates whether this is the last row in the result set -->
    <xsl:variable name='lastRow' select='position()=last() and not($gjs:gMaxItems)' />

    <!-- Flag indicating whether to use serverLink to get sub-folders or whether files are static -->
    <xsl:variable name='serverLink'>
      <xsl:choose>
        <xsl:when test='@serverLink="no"'>no</xsl:when>
        <xsl:otherwise>yes</xsl:otherwise>
      </xsl:choose>  
    </xsl:variable>

    <!-- The name of the javaScript method to call to generate the sub-folder content -->
    <xsl:variable name='subFolderMethod'>
      <xsl:call-template name='subFolderMethod' />
    </xsl:variable>

    <!-- String of evaluatable javaScript that creates a $c(1) delimited list of arguments -->
    <xsl:variable name='subFolderArguments'>
      <xsl:call-template name='subFolderArguments'>
        <xsl:with-param name='rowId' select='$rowId'/>
      </xsl:call-template>
    </xsl:variable>

    <tr
     id='{$rowId}row'
     gjsRowId='{$rowId}'
     class='treeRow'
     onkeydown='gjsTree.fnToggleKey("{$rowId}click",event);'>

      <!-- Add custom row attributes -->
      <xsl:call-template name='folderRowAttributes'>
        <xsl:with-param name='rowId' select='$rowId'/>
      </xsl:call-template>

      <!-- Generate more cells -->
      <xsl:call-template name='gjs:treeMores' />

      <td
        class='noHighlight'
        width='16'
		style='min-width:16px; max-width:16px; width:16px;'
        onclick='gjsTree.fnToggle(this)'
        id='{$rowId}click'
        gjsRowId='{$rowId}'
        gjsServerLink='{$serverLink}'
        gjsPlusId='{$rowId}plus'
        gjsHiddenRowId='{$rowId}hiddenRow'
        gjsTargetCellId='{$rowId}targetCell'
        gjsState='closed'
        gjsText=''
        gjsTextId='{$rowId}main'
        gjsRowGenerator='{$subFolderMethod}'
        gjsArguments='{$subFolderArguments}'>
        <img
         id='{$rowId}plus'
         gjsRowId='{$rowId}'
         width='16'
         height='16'>
          <xsl:choose>
            <xsl:when test='$lastRow'>
              <xsl:attribute name='src'>vcm_plus_tr.gif</xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name='src'>vcm_plus_tbr.gif</xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>
        </img>
      </td>

      <!-- Application specific content -->
      <xsl:call-template name='folderContent'>
        <xsl:with-param name='rowId' select='$rowId'/>
      </xsl:call-template>

      <!-- Expansion cell -->
      <!--<td class='noHighlight' width='2000'></td>-->
	  <td width='*'></td>
    </tr>

    <!-- Hidden row -->
    <tr
     id='{$rowId}hiddenRow'
     gjsRowId='{$rowId}'
     class='treeRow'>
      <td
       id='{$rowId}targetCell'
       gjsRowId='{$rowId}'
	   class='subrow'
       colspan='99'>
      </td>
    </tr>
    
  </xsl:template>


  <!-- This template generates markup for each leaf of a tree.
       It comprises of a table row starting with a number of cells containing 
       folder continuation lines, followed by application specific cells.
       -->
  <xsl:template name='gjs:leafContent'>
    <xsl:param name='rowId' />

      <tr
       id='{$rowId}row'
       gjsRowId='{$rowId}' 
       class='treeRow'>

        <!-- Application specific row attributes -->
        <xsl:call-template name='leafRowAttributes'>
          <xsl:with-param name='rowId' select='$rowId'/>
        </xsl:call-template>
              
        <!-- Generate mores cells -->
        <xsl:call-template name='gjs:treeLeafMores'>
          <xsl:with-param name='rowId' select='$rowId'/>
        </xsl:call-template>

        <!-- Application specific cells -->
        <xsl:call-template name='leafContent'>
          <xsl:with-param name='rowId' select='$rowId'/>
        </xsl:call-template>

        <!-- Expansion cell -->
        <!--<td class='noHighlight' width='2000'></td>-->

      </tr>

  </xsl:template>


  <!-- Private - Generate mores for a leaf within a tree -->
  <xsl:template name='gjs:treeLeafMores'>
    <xsl:param name='rowId'/>

    <xsl:call-template name='gjs:treeMores' />

    <!-- Last more column -->
    <xsl:choose>
      <xsl:when test='position()=last() and not($gjs:gMaxItems)'>
        <xsl:call-template name='gjs:treeMoreCell'>
          <xsl:with-param name='more' select='"L"'/>
          <xsl:with-param name='id' select='concat($rowId,"click")'/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name='gjs:treeMoreCell'>
          <xsl:with-param name='more' select='"T"'/>
          <xsl:with-param name='id' select='concat($rowId,"click")'/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
    
  </xsl:template>


  <!-- Private - Generate a series of more cells based on the values of the mores parameter -->
  <!-- Uses the standard recursion method for this -->
  <xsl:template name='gjs:treeMores'>
    <xsl:param name='mores' select='/ServerLink/Rows/@mores' />
    <xsl:variable
     name='more' 
     select='substring($mores,1,1)'/>
    <xsl:choose>
      <xsl:when test="string-length($more) > 0">
        <xsl:call-template name='gjs:treeMoreCell'>
          <xsl:with-param name='more' select='$more'/>
        </xsl:call-template>
        <xsl:call-template name='gjs:treeMores'>
          <xsl:with-param name='mores'>
            <xsl:value-of select="substring($mores,2)"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <!-- Template for a continuation cell -->
  <xsl:template name='gjs:treeMoreCell'>
    <xsl:param name='more'/>
    <xsl:param name='id'/>
    <td
     class='noHighlight'
     width='16px'
	 style='min-width:16px; max-width:16px; width:16px'>
    <xsl:if test='$id'>
      <xsl:attribute name='id'>
        <xsl:value-of select='$id'/>
      </xsl:attribute>  
    </xsl:if>
      <img
       width='16px'
       height='16px'>
        <xsl:choose>
          <xsl:when test='$more="T"'>
            <xsl:attribute name='src'>vcm_t.gif</xsl:attribute>
          </xsl:when>
          <xsl:when test='$more="I"'>
            <xsl:attribute name='src'>vcm_i.gif</xsl:attribute>
          </xsl:when>
          <xsl:when test='$more="L"'>
            <xsl:attribute name='src'>vcm_l.gif</xsl:attribute>
          </xsl:when>
          <xsl:when test='$more=" "'>
            <xsl:attribute name='src'>vcm_blank.gif</xsl:attribute>
          </xsl:when>
          <xsl:when test='$more="S"'>
            <xsl:attribute name='src'>vcm_blank.gif</xsl:attribute>
          </xsl:when>
        </xsl:choose>
      </img>
    </td> 
  </xsl:template>


  <!-- Public - Generate blank more cells for column heading  -->
  <xsl:template name='gjs:treeMoresMainHeading'>
    <xsl:param name='mores' select='concat(/ServerLink/Rows/@mores," ")' />
    <xsl:variable
     name='more' 
     select='substring($mores,1,1)'/>
    <xsl:choose>
      <xsl:when test="string-length($more) > 0">

          <!-- This is the output -->
          <td width='16' style='min-width:16px; max-width:16px; width:16px'></td>

        <xsl:call-template name='gjs:treeMoresMainHeading'>
          <xsl:with-param name='mores'>
            <xsl:value-of select="substring($mores,2)"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <!-- Public - Generate a sortable column heading -->
  <xsl:template name='gjs:treeColumnHeading'>
    <xsl:param name='width' select='"100"'/>
    <xsl:param name='columnId'/>
    <xsl:param name='caption'/>
    <xsl:param name='title'/>
    <xsl:param name='selected'/>
    <xsl:param name='divMainHeadId' select='"divMainHead"' />
    <xsl:param name='divReferenceHeadingId' select='concat(/ServerLink/@runId,"_mainHead")' />
    <xsl:param name='previousColumnResizable' select='1' />
    <xsl:param name='dictionary' select='"vcmCaptions.xml"' />
    
    <xsl:variable name='resultTableId' select='concat(/ServerLink/@runId,"_table")' />
    <xsl:variable name='columnOffset' select='string-length(/ServerLink/Rows/@mores)' />

    <!-- If the column is named and the user has overriden the column width then use that, otherwise use the default width -->
		<xsl:variable name='actualWidth'>
			<xsl:choose>
				<xsl:when test='$columnId and /ServerLink/tree/columnWidths/@*[name()=$columnId]'>
					<xsl:value-of select='/ServerLink/tree/columnWidths/@*[name()=$columnId]'/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select='$width'/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

    <td
	  class='columnHeadingCell'
      width='{$actualWidth}'
	  style='overflow: hidden; min-width:{$actualWidth}px; max-width:{$actualWidth}px; width:{$actualWidth}px;'
      title='{$title}'
      onclick='gjsTree.fnSort(this,{$resultTableId},{$columnOffset},"{$divReferenceHeadingId}","{$divMainHeadId}")'
      gjsColumnId='{$columnId}'>
      <div nowrap='nowrap' style='overflow: hidden; position: relative; width: 100%;'>
				<!-- Resize handle -->
				<xsl:choose>
					<xsl:when test='$previousColumnResizable=1'>
						<span
						 style='width: 5px; border-left: 1px solid darkgray; margin-top: 1px;'
						 class='columnResizeHandle'
						 onmousedown='gjsTree.fnResizeMouseDown(event,this,"{$resultTableId}","{$divReferenceHeadingId}")'
						 onclick='gjsTree.fnEventStop(event)'></span>					
					</xsl:when>
					<xsl:otherwise>
						<span
						 style='width: 5px; border-left: 1px solid darkgray; margin-top: 1px; cursor: default;'
						 class='columnResizeHandle'
						 onclick='gjsTree.fnEventStop(event)'></span>					
					</xsl:otherwise>
				</xsl:choose>
				<span nowrap='nowrap'>
				  <xsl:call-template name='gjs:i18n'>
				    <xsl:with-param name='string' select='$caption'/>
					  <xsl:with-param name='dictionary' select='$dictionary'/>
			  </xsl:call-template>
				</span>
				<xsl:choose>
				  <xsl:when test='$selected="ascending"'>
				  	<img id='gjsTree.currentSortButton' class='sortIcon' src='gjsSortAscending.gif' />    
				  </xsl:when>
				  <xsl:when test='$selected="descending"'>
				  	<img id='gjsTree.currentSortButton' class='sortIcon' src='gjsSortDescending.gif' />    
				  </xsl:when>
				  <xsl:otherwise>
				  	<img class='sortIcon' src='gjsSortNormal.gif' />
				   </xsl:otherwise>
				</xsl:choose>
			</div>
    </td>
  </xsl:template>


  <!-- ================================== Internationalisation (i18n) ================================ -->
  <!-- Parameterised message
       Usage:
       <xsl:call-template name='gjs:i18n-paramiterized'>
         <xsl:with-param name='message' select='message'/>
       </xsl:call-template>
       The message parameter should be document fragment of the following form:
       <message message='text'>
         <p1 value='123'>
         <p2 value='456'>
       </message>
       -->
  <xsl:template name='gjs:i18n-parameterized'>
    <xsl:param name='message'/>

    <xsl:variable name="language">
      <xsl:choose>
        <xsl:when test='/ServerLink/preferences/@language'>
          <xsl:value-of select='/ServerLink/preferences/@language'/>
        </xsl:when>
        <xsl:otherwise>en</xsl:otherwise> <!-- default language -->
      </xsl:choose>
    </xsl:variable>

    <xsl:choose>
      <xsl:when test='document("vcmCaptions.xml")/phrases/phrase/target[../@source=$message/@message and lang($language)]'>
        <xsl:apply-templates select='document("vcmCaptions.xml")/phrases/phrase/target[../@source=$message/@message and lang($language)]' mode='parameters'>
          <xsl:with-param name='message' select='$message'/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select='$message/@message' />
      </xsl:otherwise>
    </xsl:choose> 
  </xsl:template>

  <xsl:template match='target' mode='parameters'>
    <xsl:param name='message'/>
    <xsl:apply-templates mode='parameters'>
      <xsl:with-param name='message' select='$message'/>
    </xsl:apply-templates>
  </xsl:template>

  <!-- match target/p1, p2, etc and replace with value of p1, p2, etc that are children of  <message> -->
  <xsl:template match='target/*' mode='parameters'>
    <xsl:param name='message'/>
    <xsl:variable name='name' select='name()'/>
    <xsl:choose>
      <xsl:when test='$message/*[name()=$name]'>
        <xsl:value-of select='$message/*[name()=$name]/@value'/>
      </xsl:when>
      <xsl:otherwise>[Missing Parameter: <xsl:value-of select='$name' />]</xsl:otherwise>
    </xsl:choose>
  </xsl:template>


  <!-- Non-parameterised string
       Usage:
       <xsl:call-template name='gjs:i18n'>
         <xsl:with-param name='string' select='"string"'/>
       </xsl:call-template>
       -->
  <xsl:template name='gjs:i18n'>
    <xsl:param name='string'/>
    <xsl:param name='dictionary' select='"vcmCaptions.xml"'/>

    <xsl:variable name="language">
      <xsl:choose>
        <xsl:when test='/ServerLink/preferences/@language'>
          <xsl:value-of select='/ServerLink/preferences/@language'/>
        </xsl:when>
        <xsl:otherwise>en</xsl:otherwise> <!-- default language -->
      </xsl:choose>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test='document($dictionary)/phrases/phrase/target[../@source=$string and lang($language)]'>
        <xsl:value-of select='document($dictionary)/phrases/phrase/target[../@source=$string and lang($language)]' />
      </xsl:when>
      <xsl:otherwise>
				<xsl:choose>
				  <xsl:when test='document($dictionary)/phrases/phrase/target[../@source=$string and lang("en")]'>
				    <xsl:value-of select='document($dictionary)/phrases/phrase/target[../@source=$string and lang("en")]' />
				  </xsl:when>
				  <xsl:otherwise>
				    <xsl:copy-of select='$string' />
				  </xsl:otherwise>
		    </xsl:choose> 
      </xsl:otherwise>
    </xsl:choose> 
  </xsl:template>


  <!-- ================================== Prototypes ================================ -->

  <!-- divMainHead prototype -->
  <xsl:template name='divMainHead'>

    <xsl:variable name='resultTableId' select='concat(/ServerLink/@runId,"_table")' />
    <xsl:variable name='columnOffset' select='string-length(/ServerLink/Rows/@mores)+1' />
    
    	<table class='layoutTable' gjsTreeId='Prototype'>
    	  <tr>

          <xsl:call-template name='gjs:treeMoresMainHeading' />

          <td width='25' style='min-width:25px; max-width:25px; width:25px'></td>

          <xsl:call-template name='gjs:treeColumnHeading'>
            <xsl:with-param name='width' select='"50"'/> 
	          <xsl:with-param name='columnId'>Gaga</xsl:with-param>
            <xsl:with-param name='caption'>Gaga</xsl:with-param>
            <xsl:with-param name='selected'>ascending</xsl:with-param>
          </xsl:call-template>

          <xsl:call-template name='gjs:treeColumnHeading'>
            <xsl:with-param name='width' select='"500"'/> 
	          <xsl:with-param name='columnId'>OverrideDivMainHead</xsl:with-param>
            <xsl:with-param name='caption'>Override &lt;xsl:template name='divMainHead'&gt; to create custom column headings</xsl:with-param>
          </xsl:call-template>

          <td width='*'></td>
        </tr>
      </table>
      
  </xsl:template>


  <!-- folderContent prototype -->
  <!-- Override this template with application specific folder content -->
  <xsl:template name='folderContent'>
    <xsl:param name='rowId'/>

    <xsl:variable name='onfocus'>
      <xsl:text>gjsTree.fnItemSelect(this);</xsl:text>
      <xsl:text>Class.fnSelect(Object,this);</xsl:text>
      <xsl:text>Main.fnSetMainHead("</xsl:text>
        <xsl:value-of select='/ServerLink/@runId' />
      <xsl:text>_mainHead");</xsl:text>
    </xsl:variable>

    <!-- Icon for Object -->
    <td width='25' style='min-width:25px; max-width:25px; width:25px'>
      <img
       onmousedown='fnItemDrag(fnElement("{$rowId}main"),event);'
       ondragstart='window.event.returnValue=false'
       src='vcm_folder.gif'
       title='Generic Folder'
       width='25'
       height='16'/>
    </td>

    <!-- draggable cell -->
    <td
     width='50'
	 style='min-width:50px; max-width:50px; width:50px'
     nowrap='nowrap'>
      <span
       nowrap='nowrap'
       id='{$rowId}main'
       tabindex='0'
       onfocus='{$onfocus}'
       onmousedown='fnItemDrag(this,event);'
       title='Gaga tool-tip'
       gjsIconId='{$rowId}icon'>
        gaga<xsl:value-of select='position()'/>
      </span>
    </td>


    <!-- normal cell -->
    <td
     width='400'
     nowrap='nowrap'>
      <div nowrap='nowrap'>
        Override &lt;xsl:template name='folderContent'&gt; to create custom folder content
      </div>
    </td>
  </xsl:template>


  <!-- leafContent prototype -->
  <!-- Override this template with application specific row content -->
  <xsl:template name='leafContent'>
    <xsl:param name='rowId'/>
    
    <!-- Icon cell -->
    <td
     class='noHighlight' 
     width='25'
	 style='min-width:25px; max-width:25px; width:25px'>
      <img
       src='vcm_record_l.gif'
       title='xxx'
       width='25'
       height='16'>
      </img>
    </td>

    <!-- Main cell -->
    <td width='50' style='min-width:50px; max-width:50px; width:50px'>
      <div
       nowrap='nowrap'
       tabindex='0'>
        gaga<xsl:value-of select='position()' />
      </div>
    </td>

    <!-- Cell -->
    <td width='500'>
      <div
       nowrap='nowrap'>
        Override &lt;xsl:template name='leafContent'&gt; to create custom row content
      </div>
    </td>

  </xsl:template>  <!-- name='leafContent' -->


  <!-- tableAttributes prototype -->
  <!-- Override this template to add custom attributes to the table element -->
  <xsl:template name='tableAttributes'>
    <xsl:param name='tableId'/>
    <!-- <xsl:attribute name='title'>tool-tip for table</xsl:attribute> -->
  </xsl:template>


  <!-- folderRowAttributes prototype -->
  <!-- Override this template to add custom attributes to a folder row element -->
  <xsl:template name='folderRowAttributes'>
    <xsl:param name='rowId'/>
    <!-- <xsl:attribute name='title'>tool-tip for row</xsl:attribute> -->
  </xsl:template>


  <!-- leafRowAttributes prototype -->
  <!-- Override this template to add custom attributes to a leaf row element -->
  <xsl:template name='leafRowAttributes'>
    <xsl:param name='rowId'/>
    <!-- <xsl:attribute name='title'>tool-tip for row</xsl:attribute> -->
  </xsl:template>


  <!-- Prototype for subFolderMethod -->
  <xsl:template name='subFolderMethod'>
    <xsl:param name='rowId'/>
    
    <xsl:text>Object.fnListSub</xsl:text>

  </xsl:template>


  <!-- Prototype for subFolderMethod -->
  <xsl:template name='subFolderArguments'>
    <xsl:param name='rowId'/>

    <xsl:text>"</xsl:text><xsl:value-of select='$rowId'/><xsl:text>main"</xsl:text>  <!-- Becomes the sub-folders parentId -->
    <xsl:text>+delimiter+"argument2"</xsl:text>
    <xsl:text>+delimiter+"argument3"</xsl:text>
    <xsl:text>+delimiter+"argument4"</xsl:text>
    <xsl:text>"+delimiter+gjsTree.fnMores(gCurrentCell)</xsl:text>  <!-- Generate mores list dynamically -->

  </xsl:template>


</xsl:stylesheet>
